@@ -1,5 +1,3 @@
-import six
-
 from sevenbridges.meta.fields import (
     HrefField, StringField, BooleanField, CompoundField
 )
@@ -25,18 +23,13 @@ class Invoice(Resource):
     invoice_period = CompoundField(InvoicePeriod, read_only=True)
 
     def __str__(self):
-        return six.text_type('<Invoice: id={id}>'.format(id=self.id))
+        return f'<Invoice: id={self.id}>'
 
     def __eq__(self, other):
-        if not hasattr(other, '__class__'):
-            return False
-        if not self.__class__ == other.__class__:
+        if type(other) is not type(self):
             return False
         return self is other or self.id == other.id
 
-    def __ne__(self, other):
-        return not self.__eq__(other)
-
     @classmethod
     def query(cls, offset=None, limit=None, api=None):
         """
@@ -47,7 +40,7 @@ class Invoice(Resource):
         :return: Collection object.
         """
         api = api if api else cls._API
-        return super(Invoice, cls)._query(
+        return super()._query(
             url=cls._URL['query'], offset=offset, limit=limit, fields='_all',
             api=api
         )
